@@ -4,11 +4,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CUSTOMTOOLSPLUGIN_H
-#define CUSTOMTOOLSPLUGIN_H
+#pragma once
 
 #include "pimcommon_export.h"
 #include <QObject>
+#include <memory>
 class KActionCollection;
 namespace PimCommon
 {
@@ -40,7 +40,6 @@ public:
     Q_REQUIRED_RESULT bool isEnabled() const;
 
 private:
-    CustomToolsPluginPrivate *const d;
+    std::unique_ptr<CustomToolsPluginPrivate> const d;
 };
 }
-#endif // CUSTOMTOOLSPLUGIN_H
