@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,22 +10,22 @@
 #include <KLocalizedString>
 #include <KUrlRequester>
 
-#include <QWidget>
-#include <QLineEdit>
-#include <QGroupBox>
 #include <QButtonGroup>
 #include <QCheckBox>
+#include <QComboBox>
+#include <QGroupBox>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
+#include <QLineEdit>
 #include <QRadioButton>
 #include <QSpinBox>
-#include <QComboBox>
+#include <QVBoxLayout>
+#include <QWidget>
 
 using namespace PimCommon;
 
-static const char lockedDownWarning[]
-    = I18N_NOOP("<qt><p>This setting has been fixed by your administrator.</p>"
-                "<p>If you think this is an error, please contact him.</p></qt>");
+static const char lockedDownWarning[] = I18N_NOOP(
+    "<qt><p>This setting has been fixed by your administrator.</p>"
+    "<p>If you think this is an error, please contact him.</p></qt>");
 
 void ConfigureImmutableWidgetUtils::checkLockDown(QWidget *w, const KConfigSkeletonItem *item)
 {
@@ -45,7 +45,7 @@ void ConfigureImmutableWidgetUtils::populateButtonGroup(QGroupBox *box, QButtonG
     }
     const int numberChoices(e->choices().size());
     for (int i = 0; i < numberChoices; ++i) {
-        QRadioButton *button = new QRadioButton(e->choices().at(i).label, box);
+        auto button = new QRadioButton(e->choices().at(i).label, box);
         group->addButton(button, i);
         box->layout()->addWidget(button);
     }
